package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````T)P$"#0```"(LP```````#0`(``'
M`"@`'``;``8````T````-(`$"#2`!`C@````X`````4````$`````P```!0!
M```4@00(%($$"!,````3````!`````$````!``````````"`!`@`@`0(L*T`
M`+"M```%`````!````$`````L````#`%"``P!0AP`@``\!(```8`````$```
M`@```!2P```4,`4(%#`%"/@```#X````!@````0````$````*`$``"B!!`@H
M@00(1````$0````$````!````%'E=&0```````````````````````````8`
M```$````+VQI8B]L9"UL:6YU>"YS;RXR```$````$`````$```!'3E4`````
M``(````&````$@````0````4`````P```$=.50!_418(/M>(<H+LF1K/#.PO
M0(P,7&$```!U````"P``````````````1`````````!(````1P````````!+
M````70```#\````Z````3`````0```!9`````````#$```!B````50```#(`
M``!N````:@````4````L```````````````J````9@```!X`````````````
M`&<```!)````:`````D```!Q````4@```'0````"````3@`````````?````
M`````'(`````````40```&\``````````````&D````H````4````#L`````
M`````````%P````V````00```$8``````````````!,`````````0```````
M````````(P`````````<````,`````P````S````*0```%0`````````````
M`%X```!M````/0```&$```!-````/````#4`````````#0``````````````
M`````%8```!E`````````$4```!@````0P```#X````G`````0``````````
M````````````````````````````````````````````````````````````
M``!/```````````````````````````````/`````````!`````5````8P``
M`````````````````!0``````````````!(`````````&0``````````````
M``````````!7`````````%@`````````:P``````````````$0``````````
M`````````!L`````````;````"8````&````)`````@`````````+P```"4`
M```.````'0````````!D````(0`````````:````"@``````````````0@``
M```````T````+@````````!S````7P``````````````2@````<`````````
M`````````````````````````````````````%L````B`````````!<`````
M````<````!@`````````-P`````````K`````````````````````````%H`
M````````%@````````!3`````````````````````````#@````#````````
M`"`````M````.0```"4```!/````"`````@`````$!`$)4`$@J@!``&BA@&H
M0````D\H!"DXHC)'BH0,"$\```!1````````````````````4P```%4```!6
M````5P```%@```!9````6@```%L```!=````7@````````!?````````````
M````````8````&,``````````````&0```!F````9P```&D`````````:P``
M`&T``````````````&\```!P````<@````````#(U;)Q6>CM[,[>1RVCX/M)
MZM/O#J?=HVLOQ9NVV\WCGN?O7WN'^9R!:PE#UCGRBQP,.I<+1Y@%QL6)!9`-
M%.*>(?_D#K(!BV_$N9Q`:W^:?'^IG)MNQ=\?V7%8'+OCDGS49-1\K4OCP#)B
MV^WAIP(*9J_,9GOP2FOB1\8!0T75['U!CL7"Y3\LH2(+(/+;TQWZH6Q@N8WQ
M#@````````````````````#X`@`````````````2````1@,`````````````
M$@```+$``````````````!(```"=`P`````````````2````B`,`````````
M````$@```*$!`````````````!(```!Z`@`````````````2````$0``````
M````````(````"```````````````"````".`P`````````````2````C0$`
M````````````$@```.`#`````````````!(```!N`0`````````````2````
M@`$`````````````$@```&@#`````````````!(````O`P`````````````2
M````"0,`````````````$@```"P"`````````````!(```#]````````````
M```2````'`(`````````````$@```+(#`````````````!(```#*`0``````
M```````2````/@0`````````````$@```-<"`````````````!(````1`P``
M```````````2````F`(`````````````$@```.H!`````````````!(```"F
M`0`````````````2````-0(`````````````$@```,T#`````````````!(`
M```P!``````````````2````+P$`````````````$@```-@#````````````
M`!(````T```````````````2````Z@,`````````````$@```%T!````````
M`````!(```#(```````````````2````'@0`````````````$@```,8#````
M`````````!(````/!``````````````2````JP,`````````````$@```($#
M`````````````!(````-!0`````````````2````00$`````````````$@``
M`/\#`````````````!(```!<`@`````````````2````7P,`````````````
M$@```.L"`````````````!(```!.`@`````````````2````%@0`````````
M````$@```+D#`````````````!(```"1`@`````````````2````JP$`````
M````````$@```'`#`````````````!(```#``P`````````````2````I`,`
M````````````$@```.P``````````````!(```!"```````````````2````
M!@0`````````````$@```"@$`````````````!(```#7```````````````2
M````_@$`````````````$@```(4"`````````````!(```!0`0``````````
M```2````E@,`````````````$@```$X#`````````````!(```#Q`@``````
M```````2````'0$`````````````$@```$,"`````````````!(```!4````
M```````````2````V`$`````````````$@```&,``````````````!(````W
M!``````````````2````CP``````````````$@```%8#`````````````!(`
M``!!`P`````````````2````>```````````````$@````L!````````````
M`!(```"W`0``/)@$"``````2````K@0``&#.!`@$````$0`0`(L%``!@O00(
MFPH``!(`#@"W!0``T+4$")4!```2``X`J`0``"S.!`@`````$@`/`%($``"$
M,@4(!````"$`&0"`!```P+($"`P````2``X`-P4``*#-!`A:````$@`.`$P%
M``#`T00(ZEL``!$`$`"@````#)H$"``````2````(@4``%PR!0@`````$``8
M`/@#``"`,@4(!````!$`&0`D!0``7#(%"``````@`!@`1P4``&@R!0@$````
M$0`8`%$$``"$,@4(!````"$`&0">!```D,T$"`4````2``X`J@4``%"[!`@0
M`@``$@`.`,L$``"`JP0(1````!(`#@!0!```A#(%"`0````1`!D`2P0``#"Y
M!`@@`@``$@`.`/L$``!PMP0('P```!(`#@`6!0``H+@$"(8````2``X`;P0`
M`'`R!0@`````$`#Q_WL$``#P0@4(`````!``\?^U!````,@$")0$```2``X`
M(`,``&3.!`@$````$0`0`"@%``#0G`0(`````!(`#@#9!````+($"+0````2
M``X`[P0``)"W!`@0`0``$@`.`&H"``#\F00(`````!(```"1!```D)T$"#X`
M```2``X`:`0``'`R!0@`````$`#Q_UL%```0K00(7````!(`#@`O!0``H,P$
M"#X````2``X`=P4``&PR!0@$````$0`8`*,"``"(,@4($P```!$`&0"8!0``
ML+0$"!@!```2``X`,04``(R7!`@`````$@`,``!L:6)P97)L+G-O+C4N,3``
M7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T
M97)M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X
M:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M
M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P
M='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])
M<&%R<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T
M<'9N`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V
M86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?
M9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S
M971P=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E
M<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E
M='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K
M-C0`<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S<')I;G1F`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`
M<W1R;F-P>0!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C
M`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M
M9&ER`&UE;6-P>0!?7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y
M<&5?8E]L;V,`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``9G!R:6YT
M9@!R96%D9&ER-C0`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S
M=&%R=`!?96YD`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB
M8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E
M;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?9&%T85]S
M=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI=`!N86UE7VQO861?;7E?<&%R
M7W!L`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!S:7IE7VQO861?;7E?
M<&%R7W!L`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN
M9'!R;V<`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'3$E"0U\R+C,`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,`````(``P````,``P``````````
M``,````$```````#``4`!@`````````#`````P`"``(```````,````$``,`
M```#````!P``````!``#``,``P`#``,````#`````P`"`````P`#``,````(
M``,``P```````P`#`````````````P`#``8```````````````,````#``,`
M`````````0`!``$``0`#``$``0`!`````0`#``$``0`#``$``0`!``,``0`!
M``$``0`!``$``0`!``$``0````$``0`!``$``0````$``0````$`!0`6`P``
M$````&`````4:6D-```(`,0%```0````$VEI#0``!P#.!0``$````'(9:0D`
M``4`V`4``!`````2:6D-```$`.0%```0````$&EI#0```P#N!0````````$`
M`@#'`@``$``````````2:6D-```&`.0%```0````$&EI#0```@#N!0``````
M``PQ!0@&"```@#(%"`5:``"$,@4(!6$``(@R!0@%<@``'#$%"`<!```@,04(
M!P(``"0Q!0@'`P``*#$%"`<$```L,04(!P4``#`Q!0@'!@``-#$%"`<'```X
M,04(!T\``#PQ!0@'"```0#$%"`<*``!$,04(!PL``$@Q!0@'#```3#$%"`<-
M``!0,04(!PX``%0Q!0@'#P``6#$%"`<0``!<,04(!Q$``&`Q!0@'$@``9#$%
M"`<3``!H,04(!Q0``&PQ!0@'%0``<#$%"`<6``!T,04(!Q<``'@Q!0@'&```
M?#$%"`<9``"`,04(!QH``(0Q!0@'&P``B#$%"`<<``",,04(!QT``)`Q!0@'
M'@``E#$%"`<?``"8,04(!R```)PQ!0@'(0``H#$%"`<B``"D,04(!R,``*@Q
M!0@';```K#$%"`=8``"P,04(!R0``+0Q!0@')0``N#$%"`<F``"\,04(!R<`
M`,`Q!0@'*```Q#$%"`<I``#(,04(!RH``,PQ!0@'*P``T#$%"`<L``#4,04(
M!RT``-@Q!0@'+@``W#$%"`<O``#@,04(!S```.0Q!0@',0``Z#$%"`<R``#L
M,04(!S,``/`Q!0@'-```]#$%"`<U``#X,04(!S8``/PQ!0@'-P```#(%"`<X
M```$,@4(!SD```@R!0@'.@``##(%"`<[```0,@4(!SP``!0R!0@'/0``&#(%
M"`<^```<,@4(!S\``"`R!0@'0```)#(%"`=!```H,@4(!T(``"PR!0@'0P``
M,#(%"`=$```T,@4(!T4``#@R!0@'1@``/#(%"`='``!`,@4(!T@``$0R!0@'
M20``2#(%"`=*``!,,@4(!TL``%`R!0@'3```5#(%"`=-``!8,@4(!TX``%6)
MY5.#[`3H`````%N!PWB9``"+D_S___^%TG0%Z)X```#HK04``.A(-@``6%O)
MP_\U%#$%"/\E&#$%"`````#_)1PQ!0AH`````.G@_____R4@,04(:`@```#I
MT/____\E)#$%"&@0````Z<#_____)2@Q!0AH&````.FP_____R4L,04(:"``
M``#IH/____\E,#$%"&@H````Z9#_____)30Q!0AH,````.F`_____R4X,04(
M:#@```#I</____\E/#$%"&A`````Z6#_____)4`Q!0AH2````.E0_____R5$
M,04(:%````#I0/____\E2#$%"&A8````Z3#_____)4PQ!0AH8````.D@____
M_R50,04(:&@```#I$/____\E5#$%"&AP````Z0#_____)5@Q!0AH>````.GP
M_O___R5<,04(:(````#IX/[___\E8#$%"&B(````Z=#^____)60Q!0AHD```
M`.G`_O___R5H,04(:)@```#IL/[___\E;#$%"&B@````Z:#^____)7`Q!0AH
MJ````.F0_O___R5T,04(:+````#I@/[___\E>#$%"&BX````Z7#^____)7PQ
M!0AHP````.E@_O___R6`,04(:,@```#I4/[___\EA#$%"&C0````Z4#^____
M)8@Q!0AHV````.DP_O___R6,,04(:.````#I(/[___\ED#$%"&CH````Z1#^
M____)90Q!0AH\````.D`_O___R68,04(:/@```#I\/W___\EG#$%"&@``0``
MZ>#]____):`Q!0AH"`$``.G0_?___R6D,04(:!`!``#IP/W___\EJ#$%"&@8
M`0``Z;#]____):PQ!0AH(`$``.F@_?___R6P,04(:"@!``#ID/W___\EM#$%
M"&@P`0``Z8#]____);@Q!0AH.`$``.EP_?___R6\,04(:$`!``#I8/W___\E
MP#$%"&A(`0``Z5#]____)<0Q!0AH4`$``.E`_?___R7(,04(:%@!``#I,/W_
M__\ES#$%"&A@`0``Z2#]____)=`Q!0AH:`$``.D0_?___R74,04(:'`!``#I
M`/W___\EV#$%"&AX`0``Z?#\____)=PQ!0AH@`$``.G@_/___R7@,04(:(@!
M``#IT/S___\EY#$%"&B0`0``Z<#\____)>@Q!0AHF`$``.FP_/___R7L,04(
M:*`!``#IH/S___\E\#$%"&BH`0``Z9#\____)?0Q!0AHL`$``.F`_/___R7X
M,04(:+@!``#I</S___\E_#$%"&C``0``Z6#\____)0`R!0AHR`$``.E0_/__
M_R4$,@4(:-`!``#I0/S___\E"#(%"&C8`0``Z3#\____)0PR!0AHX`$``.D@
M_/___R40,@4(:.@!``#I$/S___\E%#(%"&CP`0``Z0#\____)1@R!0AH^`$`
M`.GP^____R4<,@4(:``"``#IX/O___\E(#(%"&@(`@``Z=#[____)20R!0AH
M$`(``.G`^____R4H,@4(:!@"``#IL/O___\E+#(%"&@@`@``Z:#[____)3`R
M!0AH*`(``.F0^____R4T,@4(:#`"``#I@/O___\E.#(%"&@X`@``Z7#[____
M)3PR!0AH0`(``.E@^____R5`,@4(:$@"``#I4/O___\E1#(%"&A0`@``Z4#[
M____)4@R!0AH6`(``.DP^____R5,,@4(:&`"``#I(/O___\E4#(%"&AH`@``
MZ1#[____)50R!0AH<`(``.D`^____R58,@4(:'@"``#I\/K__P`````Q[5Z)
MX8/D\%!44FB0S00(:*#-!`A15F@PN00(Z#O\___TD)"0D)"0D)"0D)"0D)!5
MB>53@^P$@#V<,@4(`'4_H:`R!0B[##`%"('K"#`%",'[`H/K`3G8<QZ-M@``
M``"#P`&CH#(%"/\4A0@P!0BAH#(%"#G8<NC&!9PR!0@!@\0$6UW#C70F`(V\
M)P````!5B>6#[!BA$#`%"(7`=!*X`````(7`=`G'!"00,`4(_]#)PY"0D)"0
MD)"0D)"0D)!5B>56BW4(4P^V#HGPA,ET*:%XT`0(C58!#[88B?#K"@^V"H/"
M`83)=!`XV77R#[8*B="#P@&$R77P6UY=PV:053'2B>57B<=6@\<<4X'L4`$`
M`(VUM/[__XF%K/[__Y"+#)>)R(G+P>,8P>@8"=B)R\'C"('C``#_`,'I"`G8
M@>$`_P``"<B)!):#P@&#^A!USHV5Z/[__XU-Z)"-="8`BT+L,P(S0M0S0LS!
MR!^)0@R#P@0YRG7HBX6L_O__BY6L_O__BP")T8F%J/[__XM!$(N-J/[__XMR
M!(MZ"`.%M/[__XM2#,')&XV,")EY@EJ)\(G[]]`A\R'0"=B+G:C^__\!P8N%
MJ/[__\'.`@.5N/[__R'S]]`A^`G8BYVH_O__C90"F7F"6HG(P<@;`<(#O;S^
M__^)T,'(&\'+`HV$!YEY@EJ)SXF%I/[__XG((=_WT"'P`[7`_O__"?@#A:3^
M__^)U\')`HFUI/[__XG6(<_WUB'>"?Z+O:3^__\#G<3^___!R@*-M#>9>8):
MB;6P_O__B<;!SAL#M;#^__^)]\'/&XV\.YEY@EJ)PXF]I/[___?3B<<AUR'+
M"?N)]P.=I/[__P.-R/[__\'(`B''B8VD_O__B?'WT2'1"?F+O:3^__\#E<S^
M___!S@*-C`^9>8):B8VP_O__B=G!R1L#C;#^__^)S\'/&XV\.IEY@EJ)VO?2
M(<(#A=#^__^)O:3^__^)WR'W"?J)SP.5I/[__XF%I/[__XG(P<L"]]`AWR'P
M"?B+O:3^__\#M=3^___!R0*-A`>9>8):B86P_O__B[VP_O__B=#!R!L!QXGX
MP<@;C80&F7F"6HG6B86D_O__B=`ASO?0(=@#G=C^__\)\`.%I/[__XG^P<H"
MB9VD_O__B?LAUO?3(<L)\XNUI/[__P.-W/[__\'/`HV<'IEY@EJ)G;#^__^)
MP\'+&P.=L/[__XG>P<X;C;0QF7F"6HG!]]$AT0.5X/[__XFUI/[__XG&(?X)
M\8G>`XVD_O__B96D_O__B=K!R`+WTB'&(?H)\HNUI/[__P.]Y/[__\'+`HV4
M%IEY@EJ)E;#^__^+M;#^__^)RL'*&P'6B?+!RAN-E!>9>8):B<^)E:3^__^)
MRB'?]](AP@.%Z/[__PGZ`Y6D_O__B??!R0*)A:3^__^)\"'/]]`AV`GXB[VD
M_O__`YWL_O__P<X"C80'F7F"6HF%L/[__XN]L/[__XG0P<@;`<>)^,'(&XV$
M`YEY@EJ)TXF%I/[__XG0(?/WT"'(`XWP_O__"=@#A:3^__^)^\'*`HF-I/[_
M_XGY(=/WT2'Q"=F+G:3^___!SP*-C`N9>8):B8VP_O__BYVP_O__B<'!R1L#
MM?3^__\!RXG9P<D;C8P.F7F"6HG&B8VD_O__B<$A_O?1(=$#E?C^__\)\0.-
MI/[__XG>P<@"B96D_O__B=HAQO?2(?H)\HNUI/[__P.]_/[__\'+`HV4%IEY
M@EJ)E;#^__^+M;#^__^)RL'*&P'6B?+!RAN-E!>9>8):B<^)E:3^__^)RB'?
M]](AP@GZB?<#E:3^___!R0(#A0#___\ASXF%I/[__XGP]]`AV`GXB[VD_O__
MP<X"`YT$____C80'F7F"6HGWB86P_O__B=`QS\'(&S'7`X6P_O__C;P[H>O9
M;L'*`HG#P<L;`XT(____C1P?B=<Q]S''C;PYH>O9;HG9P<@"P<D;`[4,____
MC0P/B<<QUS'?C;P^H>O9;HG.P<L"P<X;`Y40____C30WB=\QQS'/C;PZH>O9
M;HGRP<D"P<H;`X44____C107B<\QWS'WC;PXH>O9;HG0P<@;`<?!S@*)\`.=
M&/___S'(,=#!R@*-G`.AZ]ENB?C!R!L#C1S___^-!`.)TS'S,?N-G!FAZ]EN
MB<'!SP+!R1L!RXGY`[4@____,=$QP<'(`HVT#J'KV6Z)V<')&P.5)/___XT,
M#HG&,?XQWHVT,J'KV6Z)RL'+`L'*&P'6B=H#O2C___\QPC'*P<D"C;P7H>O9
M;HGRP<H;`X4L____C107B<\QWS'WC;PXH>O9;HG0P<@;`<?!S@*)\`.=,/__
M_S'(,=#!R@*-G`.AZ]ENB?C!R!L#C33___^-!`.)TS'S,?N-G!FAZ]ENB<'!
MSP+!R1L!RXGY`[4X____,=$QP<'(`HVT#J'KV6Z)V<')&P.5//___XT,#HG&
M,?XQWHVT,J'KV6Z)RL'+`L'*&P'6B=H#O4#___\QPC'*P<D"C;P7H>O9;HGR
MP<H;`X5$____C107B<\QWS'WC;PXH>O9;HG0P<@;`<?!S@*)\`.=2/___S'(
M,=#!R@*-G`.AZ]ENB?C!R!L#C4S___^-!`.)TS'S,?N-G!FAZ]ENB<'!SP+!
MR1N-#`N)^P.U4/___S'3,<,#E53___^-M!ZAZ]ENB<O!R`+!RQN-'!Z)QHF5
MI/[__PG^B<(A^B'."=:+E:3^__\#O5C____!R0*-M#+<O!N/B=K!RAN-%!:)
MSHF]I/[__PG&B<\AQR'>"?Z+O:3^__\#A5S____!RP*-M#?<O!N/B=^)A:3^
M__\)SXG8B;6P_O__B=;!SAL#M;#^__\AUR'("<>+A:3^__\#C6#____!R@*-
MO#C<O!N/B?#!R!N-!`>)UXF-I/[__PG?B=$AV2'W"<^+C:3^__\#G63____!
MS@*-O#G<O!N/B<'!R1N-#`^)]XF=I/[__PG7B?,ATR''"=^+G:3^__\#E6C_
M___!R`*-O#O<O!N/B<O!RQN-'!^)QXF5I/[__PGWB<(A\B'/"=>+E:3^__\#
MM6S____!R0*-O#K<O!N/B=K!RAN-%!>)SXFUI/[__PG'B<XAWR'&"?>+M:3^
M___!RP*-O#[<O!N/B=;!SAL#A7#___^--#>)WPG/B86D_O__B=@AUR'("<>+
MA:3^__\#C73____!R@*-O#C<O!N/B?#!R!N-!`>)UXF-I/[__PG?B=$AV2'W
M"<^+C:3^__\#G7C____!S@*-O#G<O!N/B<'!R1N-#`^)]XF=I/[__PG7B?,A
MTR''"=^+G:3^__\#E7S____!R`*-O#O<O!N/B<O!RQN-'!^)QXF5I/[__PGW
MB<(A\B'/"=>+E:3^__\#=8#!R0*-O#K<O!N/B=K!RAN-%!>)SXFUI/[__PG'
MB<XAQB'?"?>+M:3^__^-O#[<O!N/B=;!SAL#183!RP*--#>)WXF%I/[__PG/
MB=@AR"'7"<>+A:3^__\#38C!R@*-O#C<O!N/B?#!R!N-!`>)UXF-I/[__PG?
MB=$AV2'W"<^+C:3^__\#78S!S@*-O#G<O!N/B<'!R1N-#`^)]XF=I/[__PG7
MB?,ATR''"=^+G:3^__\#59#!R`*-O#O<O!N/B<O!RQN-'!^)QXF5I/[__PGW
MB<(A\B'/"=>+E:3^__\#=93!R0*-O#K<O!N/B=K!RAN-%!>)SXFUI/[__PG'
MB<XAWR'&"?>+M:3^__\#19C!RP*-O#[<O!N/B=;!SAN--#>)WXF%I/[__PG/
MB=@AR"'7"<>+A:3^__\#39S!R@*-O#C<O!N/B?#!R!N-!`>)UXF-I/[__PG?
MB=$AV2'W"<^+C:3^__\#7:#!S@*-O#G<O!N/B<'!R1L!SXGQB9VD_O__"=&)
M\R'3(<$)V8N=I/[__\'(`@-5I(V,"]R\&X^)PXF-L/[__XGY,?/!R1LQ^P.-
ML/[__XV<&M;!8LK!SP*)RL'*&P'3B?H#=:@QPC'*P<D"C;06UL%BRHG:P<H;
M`T6LC106B<XQ_C'>C;0PUL%BRHG0P<L"P<@;`<:)V`-]L#'(,=#!R@*-O`?6
MP6+*B?#!R!L#3;2-!`>)US'?,?>-O#G6P6+*B<'!R1O!S@(!SP-=N(GQ,=$Q
MP8V<"];!8LJ)^<'(`L')&P-5O(T,"XG#,?,Q^XV<&M;!8LJ)RL'/`L'*&P'3
MB?H#=<`QPC'*P<D"C;06UL%BRHG:P<H;`T7$C106B<XQ_C'>C;0PUL%BRHG0
MP<L"P<@;`<:)V`-]R#'(,=#!R@*-O`?6P6+*B?#!R!L#3<R-!`>)US'?,?>-
MO#G6P6+*B<'!R1O!S@(!SP-=T(GQ,=$QP8V<"];!8LJ)^<'(`L')&P-5U(T,
M"XG#,?,Q^XV<&M;!8LJ)RL'/`L'*&P'3B?H#==@QPC'*P<D"C;06UL%BRHG:
MP<H;`T7<C106B<XQ_C'>C;0PUL%BRHG0P<L"P<@;`<:)V`-]X#'(,=#!R@*-
MO`?6P6+*B?#!R!L#3>2-!`>)US'?,?>-O#G6P6+*B<'!S@+!R1L#7>B-#`^)
M]S'7,<>-O#O6P6+*B<O!R`+!RQL#5>R-'!^)QS'W,<^-O#K6P6+*B=K!RAL!
MUXN5J/[__P-5\,')`HVT%M;!8LJ)RC'",=J-%!:)_L'.&P'RB[6L_O__P<L"
MB18!?@0!7@@!3@P!1A"!Q%`!``!;7E]=PXVV`````(V\)P````!5B>6#[#B%
MP(E=](G#B77XB7W\B57<=1`QP(M=](MU^(M]_(GL7<.0H80R!0B%P(E%X'3D
M#[8#/#UT783`B=IT5X/"`0^V`CP]=`2$P'7R*=J+1>"+,(7V=+Z)7>2)QXG3
MC;0F`````(M%Y(E<)`B)-"2)1"0$Z-'P__^%P'4&@#P>/70;@\<$BS>%]G7:
M9I#KAHVV`````#'2Z[6-="8`*WW@BT7<P?\"B3B-1!X!Z6;___^-M@````"-
MOP````!5B>6#[!B-5?3H,O___\G#58GE@^P(H60R!0B#^/]T",G#C;8`````
MN&C.!`CHSO___X7`=!H/M@"$P'03/#`/E<`/ML"C9#(%",G#C70F`#'`Z_&-
MM@````"-OP````!5B>56B<93@^P0C5WTZQF0BT7TP>`"`P6$,@4(@\`$BQ"%
MTHE0_'7TB=J)\.BO_O__A<!UVX/$$%M>7<.-="8`58GE@>Q($```B7W\C;WD
M[___B5WTB=-EH10```")1>0QP(EU^(F-U.___\=$)`C_#P``B7PD!,<$)'+.
M!`CH.>___X7`?GF-</^`O#7D[___`'1DB<:)="0(QT0D!"\```")/"3H<N__
M_X7`=%+'!"0`````Z,+O__^+`(D$).BH[/__B70D#(E\)`B)7"0$B00DZ/3M
M__^+1>1E,P44````=4J+7?2+=?B+??R)[%W#C;0F`````(7V=9J-="8`QP0D
M`````.AP[___BP")!"3H5NS__XN5U.___XE<)`2)5"0(B00DZ"#L___KJN@Y
M[O__C;8`````C;PG`````%6)Y8/L&,<$)`````#H*N___XL`B00DZ!#L___'
M1"0$_____XD$).A0[/__QP0D`````.@$[___BP")!"3HZNO__\=$)`@`````
MQT0D!'"M!`B)!"3H0N___\G#C70F`%6)Y5.#[!3'!"0`````Z,GN__^+`(D$
M).BOZ___B00DZ%?J__^+`(M8!,<$)`````#HIN[__XL`B00DZ(SK__^)!"3H
MU.K__P^V`(A#&,<$)`````#H@N[__XL`B00DZ&CK__^)!"3H$.K__XL`BU@$
MQP0D`````.A?[O__BP")!"3H1>O__XD$).B=ZO__BP`/MT`09B7_`6:)0QK'
M!"0`````Z#/N__^+`(D$).@9Z___B00DZ,'I__^+`(M8!,<$)`````#H$.[_
M_XL`B00DZ/;J___'1"0(`````,=$)`0,T`0(B00DZ'[M__^)0QS'!"0`````
MZ-_M__^+`(D$).C%ZO__B00DZ&WI__^+`(M8!,<$)`````#HO.W__XL`B00D
MZ*+J__^)!"3HRNG__XL`B4,@QP0D`````.B9[?__BP")!"3H?^K__XD$).@G
MZ?__BP"+6`3'!"0`````Z';M__^+`(D$).A<ZO__B00DZ(3L__\QTHL`A<!T
M(\<$)`````#H4.W__XL`B00DZ#;J__^)!"3H7NS__XL`BU!LB5,DQP0D````
M`.@J[?__BP")!"3H$.K__XD$).BXZ/__BP"+0`3'0"@`````QP0D`````.@`
M[?__BP")!"3HYNG__XD$).B.Z/__BP"+0`3'0"P`````QP0D`````.C6[/__
MBP")!"3HO.G__XD$).ADZ/__BP"+6`3'!"0`````Z+/L__^+`(D$).B9Z?__
MB00DZ''L__^+`(E#,(/$%%M=PXUV`(V\)P````!5B>57B<=64X'LC````(7`
M=`6`.`!U$8'$C````%M>7UW#C;8`````B00DZ-SI__^%P(G&=.%FD(DT).@\
MZO__A<`/A,````"-6!,/MA6"S@0(#[9`$SG0#X3*````#[85@<X$"#G0#X33
M````B3PDZ#?J__^)'"2)18#H+.K__XM5@(U$`@*)!"3HS>K__XE%A(E<)`R)
M?"0(QT0D!(3.!`B)!"3H<N?__XU%B(E$)`B+183'!"0#````B40D!.CXY___
M@_C_=!.+19@E`/```#T`0```#X2,````BT6$B00DZ-7I__^+182)!"3HRNC_
M_XDT).B"Z?__A<`/A4;___^-M@````")-"3H_.G__XD\).ATZO__@<2,````
M6UY?7<.0C70F``^V4P$Z%8/.!`@/A`#____I(?___XUV``^V0P$Z!8+.!`@/
MA1W___\/MD,".@6#S@0(#X38_O__Z0C___^-=@"+183HD/[__^ER____C70F
M`(V\)P````!5B>53B<.#[!3'!"0`````Z/?J__^+`(D$).C=Y___B00DZ!7J
M__^)7"0$QP0D`P```(E$)`CH(>C__X7`=`F#Q!0QP%M=PY#'!"0`````Z+CJ
M__^+`(D$).B>Y___B00DZ-;I__^+0!`E`/```#T`0```="W'!"0`````Z(OJ
M__^+`(D$).AQY___B00DZ*GI__^+0!`E`/```#T`H```=9V)'"3'1"0$`@``
M`.BZY___A<`/E,"#Q!0/ML!;7<-5B>6![#@@``")7?2-G>/O__]EH10```")
M1>0QP(EU^(E]_.C4Y?__QT0D#'W.!`C'1"0$BLX$"(D<)(E$)`CHF.7__X7`
M>2`QVXM5Y&4S%10```")V'57BUWTBW7XBWW\B>Q=PXUV`(V]XM___\=$)`@`
M$```B7PD!(D<).@*Z?__A<")QGC`C4`!B00DZ(GH__^%P(G#=+&)="0(B7PD
M!(D$).BCY___Q@0S`.N;Z(CH__^-M@````"-OP````!5B>6#[`C)Z33___^-
M="8`58GE5U:)QE,QP(/L/(G3@#H]#Y3``<.)'"3H?>?__XU5Y(G'B?#HM??_
M_X7`=#&)!"2)1=#H8N?__S')BU70.<</AW4!``"0#[8$"X@$"H/!`83`=?*#
MQ#PQP%M>7UW#H80R!0@QTKD(````@S@`=!B-M"8`````@\(!BPR0A<EU]HT,
ME0@```"#/<`R!0@`="Z)3"0$B00DB570Z.OD__^%P(G!HX0R!0B+5=`/A1<!
M``"#Q#RX_____UM>7UW#B0PDQP7`,@4(`0```(E5T.AWY___BU70A<")P735
MC025`````(E%U(E$)`BAA#(%"(D,)(E$)`2)3<SHS.?__XM-S(D-A#(%"(M5
MT,=$D00`````B57D#[86@/H]#X2V````A-*)\'4+Z:L```!FD(32=`Z#P`$/
MMA"`^CV-=@!U[BGPBU74C40X`@,5A#(%"(D$)(E5T.CPYO__BU70A<")`@^$
M2O___XM5Y*&$,@4(BP20#[86A-*($'0D@/H]=!^#Q@'K"Y"`^CV0C70F`'0/
M#[86@\`!@\8!A-*($'7GQ@`],=)FD`^V#!.(3!`!@\(!A,EU\>F:_O__BT7D
MP>`"B474Z4W___^-!)4`````B474Z3/___\QP.ED____58GE5[^@S@0(5E.[
MELX$"(/L;(UUV,=%T*#.!`C'1=26S@0(QT78H\X$",=%W)G.!`C'1>">S@0(
MQT7D#-`$".LJC;8`````BT4(B10DB56\B40D!.@"YO__A<!T.H`[`'0JBP:)
MWX/&!(G#B?CH3?;__X7`B<)T!8`X`'7*BU4(B?CHF/W__X`[`'76@\1L6UY?
M7<.-=@"+30B)#"3H&>7__XE%Q*%\T`0(B00DZ`GE__^+5;R)%"2)1<#H^^3_
M_XM-P(E%M(M%Q(U,"`&+1;0!R(D$).B1Y?__BU6\QT0D!+O/!`B)5"00B<&A
M?-`$"(D,)(E-O(E$)`R+10B)1"0(Z"7B__^+3;R)^(G*Z`W]___I1O___Y"-
MM"8`````58GE5U:#[#!EH10```")1?0QP*%4T`0(B472H5C0!`B)1=:A7-`$
M"(E%VJ%@T`0(B47>H630!`B)1>*A:-`$"(E%YJ%LT`0(B47JH7#0!`B)1>X/
MMP5TT`0(9HE%\KBPS@0(Z)CU__^XN<X$".B.]?__N,'.!`CHA/7__[C*S@0(
MZ'KU__^XT<X$".AP]?__N.'.!`CH9O7__[CMS@0(Z%SU__^X:,X$".A2]?__
MN/;.!`CH2/7__[@`SP0(Z#[U__^X"L\$".@T]?__N!?/!`CH*O7__[@@SP0(
MZ"#U__^X*\\$".BV]/__A<!T#(G"N/;.!`CH!OS__[@\SP0(Z)ST__^%P'0,
MB<*X3L\$".CL^___N%G/!`CH@O3__X7`="Z)PKCMS@0(Z-+[__^ZA<\$"+C1
MS@0(Z,/[__^+1?1E,P44````=4>#Q#!>7UW#N&G/!`CH1O3__X7`=!*)PKAH
MS@0(Z);[___KPHUT)@"-=>._>L\$"+D*````\Z9UK8U5[;AHS@0(Z'+[___K
MGNC7X___C70F`(V\)P````!5B>6#[!CH,>/__XD$).@)X___B<(QP(72=`*+
M`LG#D%6)Y593@^P0BUT(A=MT88`[`'1<B1PDZ,#B__^-1`/_.<,/@]T```"+
M-7C0!`@/M@@/MA8XT70,ZUJ-M@`````X"'50@^@!.<-R]3G8C78`=58/M@`Z
M!@^$BP```(EU"(/$$%M>7>F1Y/__D(UT)@#'!"0"````Z!#C__^%P'0%9L<`
M+@"#Q!!;7EW#C70F`#@0=+>#Z`$YPW+U.=B-=@!TL(VV`````(/H`3G#<P</
MMA`Z%G3RB<(QP"G:C4H"@?D`$```=[Z#P@&)5"0(B5PD!,<$).`R!0CH/N#_
M_[C@,@4(ZZ"-=@#'!"0"````Z)CB__^)PC'`A=)TB6;'`BX`B=#K@(LU>-`$
M".D[____58GE5U93@^P<BW4(B30DZ-S^__\/M@B)QXG#A,ET*Z%XT`0(C5<!
M#[8`ZPZ-="8`#[8*@\(!A,ET$#C!=?(/M@J)TX/"`83)=?#HD?+__X7`=!V%
M]G09@#X`=!3'1"0$A\\$"(D<).@`XO__.=AT"(/$'%M>7UW#@\0<B?!;7E]=
MZ9KV__^-=@"-O"<`````58GE@^3P5E.#[#B-11")1"0(C44,B40D!(U%"(D$
M).CHXO__QT0D"#R8!`C'1"0$/)@$",<$)`R:!`CHX!,``,<$)`````#H\-__
M_X`X`'4[Z-;?__^%P*/@0@4(#X2Q`0``B00DZ)'@___'!"0`````Z*7B__^+
M`(D$).B+W___B00DZ`/B___&``#'!"0`````,=OH@N+__XL`B00DZ&C?__^)
M!"3H@.+__X`(`L<$)`````#H8>+__XL`B00DZ$??__^)!"3H7^+__X`(`8M5
M"(E<)"R#P@6)5"0HWVPD*-@%G-$$"-T%H-$$"-G)VNG?X)X/AP4!``#!X@*)
M%"3HEN'__XMU#*/L0@4(BQ;'0`2,SP0(QT`(P-$$",=`#(_/!`B)$(M=",<%
MZ$(%"`0```"#^P%^%;H!````9I"+#):)3)`,@\(!.=-_\H/#`\<$F`````")
M1"0,H>!"!0B)7"0(QT0D$`````#'1"0$X,P$"(D$).A_W?__A<")PW0]H>!"
M!0B)!"3H+.#__[CAS@0(Z*;P__^%P'0ZH>!"!0B)!"3H0=W__^C\WO__@\0X
MB=A;7HGL7<.0C70F`*'@0@4(B00DZ-_=__^)P^NRC;0F`````*'D0@4(A<!T
M"HD$).B'_?__Z[.X[<X$".A+\/__A<"CY$(%"'2@Z^''1"0$B#(%",<$))/.
M!`CH:.#__\<$)`$```#H3.'__U6)Y5=64X'L3!```(M%"&6+%10```")5>0Q
MTHMU#(F%U.___[CMS@0(Z/+O__^+'7C0!`B)7"0$B<>+A=3O__^)!"3H=-__
M_X7`=#&+E=3O__^X"L\$".@D]___BU7D93,5%````(N%U.___P^%F0$``('$
M3!```%M>7UW#BY74[___B10DZ)'>__^)-"2)A=#O__^A?-`$"(E$)`3H:M__
M_X7`B<9TI(N5T.___X/"`8F5T.___Y"`/@!U!;Z"S@0(A?]T%(ET)`2)/"3H
M2N#__X7`#X3*````B30DZ#K>__\/ME0&_SH3=1>-%`9FD`^V2OZ#Z`'&0O\`
M@^H!.@MT[@.%T.___SW_#P``#X\Y____BY74[___C87D[___B5PD#(ET)`C'
M1"0$N\\$"(E4)!")!"3H4=O__\<$)`````#HM=___XL`B00DZ)O<__^)!"3H
MT][__XV5Y.___XE4)`3'!"0#````B40D".BYV___A<!U+<<$)`````#H>=__
M_XL`B00DZ%_<__^)!"3HE][__XM`$"4`\```/0"```!T)*%\T`0(QP0D````
M`(E$)`3H4][__X7`B<8/A?7^___IA/[__XV%Y.___\=$)`0!````B00DZ'[<
M__^%P'7"C97D[___N`K/!`CHCO7__XV5Y.___XD4).@\W___B874[___Z5'^
M___HW-W__U6)Y5=64X'LG($``(M%"&6+%10```")5>0QTL>%*'___Y+/!`C'
MA2Q___^:SP0(B86@?O__N.W.!`C'A3!___^"S@0(QX4T?___#-`$",>%$'__
M_T[/!`C'A11___]'SP0(QX48?___G\\$",>%''___Y7/!`C'A2!___^GSP0(
MQX4D?___#-`$",>%.'___ZO/!`C'A3Q___^PSP0(QX5`?___#-`$".AC[?__
MA<!T"8`X``^%W@,``(VV`````.A+^?__A<")QP^$\0,```^V'X3;="+HL=O_
M_XGZC78`BP@/OMOV!%D(=0/&`E^#P@$/MAJ$VW7HC9T4?___N$[/!`CK$8UV
M`(L#@\,$@#@`#X1"`P``Z/7L__^%P(G&=.?HNO+__X7`=-Z)-"3H^MW__X7`
M=-*)QHDT).C,V___B3PDB</HPMO__XV4`P0$``")%"2)E91^___H7=S__XN5
ME'[__XD4)(G#Z$W<__^+#7C0!`B)?"04QT0D$(?/!`B)="0(B4PD#,=$)`2Y
MSP0(B86D?O__B00DZ-W8__^+O:1^___'1"0$P`$``(D\).CWV/__@_C_=1#H
MK=C__XL`@_@1#X4\`P``BXVD?O__C86P?O__B40D",<$)`,```")3"0$Z%+:
M__^#^/\/A-<'``"+A<!^__\E`/```#T`0```#X7W`0``B[7(?O__Z#C;__\Y
MQ@^%Y`$``(N%P'[__R7_`0``/<`!```/A<X!``"XF<X$".C4Z___A<`/A+4"
M``")!"3HX-S__XN5H'[__XE$)`2+`HD$).B0^___A<")P@^$CP(``(D4)(F5
ME'[__^B4VO__BY64?O__@_@#B86<?O__?F^-=`+\O\+/!`BY!0```/.F=5V#
MO9Q^__\$=!6+O9Q^__^+#7C0!`@/MD0Z^SH!=3^+O:!^__^+?P2%_XF]G'[_
M_W0LB3PDB964?O__Z#+:__^+E91^__^#^`-V$XUT!_RY!0```+_'SP0(\Z9T
M!Y")E9Q^__^)G:!^___H%^O__X7`=22+A9Q^___'1"0$`````(D$).B)V___
MA<")A9Q^__\/A10"``"ZA<\$"+AHS@0(Z##R__\Q]NA5U___BY6D?O__QT0D
M%`S0!`C'1"0$X,\$"(D<)(E4)`B)1"00H7C0!`B)1"0,Z`;7__^+O:1^___K
M2&:0Z.?6__^#.!%U48VV`````.@'U___BPUXT`0(@\8!QT0D&`S0!`B)="04
MB7PD"(E,)`S'1"0$[L\$"(E$)!")'"3HMM;__\=$)`3``0``B1PDZ-;6__^#
M^/]TI8N]I'[__XD\).@SV/__B=JX[<X$".A[\?__B1PDZ%/S___K-I"+C:1^
M__^+O:!^__^)3"0,BP?'1"0$]-`$"(E$)`BA@#(%"(D$).AQV?__QX6@?O__
M`````(M5Y&4S%10```"+A:!^__\/A4L&``"!Q)R!``!;7E]=PV:0C;4L?___
MNY+/!`CK#8UV`(L>@\8$@#L`=!N)V.AG[___,=*%P'3IB1PDZ*7:__^%P(G"
M=-N)UNFD_/__C70F`(D$)(F%E'[__^BJ\O__BX64?O__B00DZ'C:__^)A:!^
M___I=O___Y"-G3Q___^XJ\\$")"-="8`Z#OI__^%P'0,B00DZ$O:__^%P'59
MBP.#PP2`.`!UX;__SP0(Z?_[__^+C:!^__^+$>ED_?__BY6@?O__B40D$(E\
M)`R+`L=$)`2`T`0(B40D"*&`,@4(B00DZ&W8___'A:!^__\`````Z??^__^)
MQ^F*^___QT0D#`(```#'1"0$[O___\=$)`C_____B00DZ`?6__^+C9Q^__^-
ME41____'1"0(!@```(E4)`2)#"3H9];__X"]1'___P!U#8"]17___T,/A'0$
M``"+A9Q^___'1"0,`````,=$)`0`````QT0D"`````")!"3HJ]7__XV58/__
M_\>%1/___P$C16?'A4C___^)J\WOQX5,_____MRZF,>%4/___W94,A#'A53_
M___PX=+#QX58____`````,>%7/___P````#'1:``````B96$?O__B9V8?O__
MBY6<?O__C85$?___QT0D"`"```")1"0$B10DZ*S5__^%P(G##XYQ`0``BXU8
M____C;U$?___BX5<____C139.<J#T`")A5S___^)V,'H'0&%7/___XM%H(F5
M6/___X7`=%:Z0````(G?*<(YTWX"B=>-C6#___^-!`&-E41___^)?"0(B50D
M!(D$).@\UO__BT6@`?B#^$")1:`/A5____^-C41___\I^XV%1/___XT\.>B9
MV?__D(/[/P^.O````#'VD(UT)@"+!#>)A6#___^+1#<$B85D____BT0W"(F%
M:/___XM$-PR)A6S___^+1#<0B85P____BT0W%(F%=/___XM$-QB)A7C___^+
M1#<<B85\____BT0W((E%@(M$-R2)182+1#<HB46(BT0W+(E%C(M$-S")19"+
M1#<TB464BT0W.(E%F(M$-SR#QD")19R-A43____H\]C__XG8*?"#^#\/CU[_
M__^#ZT")V,'H!HG"P>(&C7PZ0"G3B7PD!(V]8/___XE<)`B)/"3H.=7__XE=
MH.EE_O__BXV<?O__BYV8?O__B0PDZ*W5__^+M5C___^+E5S___^)\,'H`X/@
M/\:$!6#___^`@\`!@_@X#X^$`0``N3@```"-O6#___\IP8T$!XF5E'[__XE,
M)`C'1"0$`````(D$).B+T___BY64?O__B=#!Z!B(19B)T,'H$(A%F8G0P>@(
MB$6:B?#!Z!B(19R)\,'H$(A%G8GPP>@(B$6>B?`Q]HA%GXV%1/___XA5FXU]
MI^@!V/__BY5$____B='!Z1B)R(A-T(G1P>D0B$W1B=&(5=.+E4C____!Z0B(
M3=*)T<'I&(A-U(G1P>D0B$W5B=&(5=>+E4S____!Z0B(3=:)T<'I&(A-V(G1
MP>D0B$W9B=&(5=N+E5#____!Z0B(3=J)T<'I&(A-W(G1P>D0B$W=B=&(5=^+
ME53____!Z0B(3=Z)T<'I&(A-X(G1P>D0B$WAB='!Z0B(3>*(5>/K!0^V1#70
M#[;`@\8!B3PD@\<"B40D",=$)`3;SP0(Z$+1__^#_A1UV<9%SP"-5:?'1"04
M#-`$"(L->-`$"(N]I'[__XE4)!#'1"0$S,\$"(E,)`R)?"0(B1PDZ`;1___I
M8/K__XV]8/___[E`````*<&-!`>)3"0(B964?O__QT0D!`````")!"3H!]+_
M_XV%1/___^C`UO__B[V$?O__N0X````QP/.KBY64?O__Z5W^___HG=#__XN]
MI'[__XN5H'[__XL`B7PD#(E$)!"+`L=$)`2\T`0(B40D"*&`,@4(B00DZ)S3
M___'A:!^__\`````Z2;Z__^`O49___]!#X5_^___@+U'?___0P^%<OO__X"]
M2'___T@/A67[__^`O4E___]%#X58^___B[V<?O__QT0D#`(```#'1"0$QO__
M_\=$)`C_____B3PDZ`/1__^-A41____'1"0(*0```(E$)`2)/"3H:='__XV5
M1'___\=$)!0,T`0(Z;C^___H0=/__Y"-="8`58GE5U93@^PLQP0D`````.@W
MU/__BP")!"3H'='__XD$).B5T?__Q@`!N-'.!`CH/./__X7`=`F`.#$/A!<#
M``"-M"8`````Z(/M___'!"0`````Z//3__^+`(D$).C9T/__QT0D#`L```#'
M1"0(`0```,=$)`0&T`0(B00DZ'G0__^%P`^$W0```(M`##'VNP$```"+0!B)
M1>2AZ$(%"(/X`7\ZZ;,```"-M@````"+1PR+%>Q"!0B+%)J)1"0$B10DZ*33
M__^%P`^%B````*'H0@4(@\,!@\8!.=A^?L<$)`````#H8=/__XL`B00DZ$?0
M__^+5>3'1"0,`````(ET)`B)5"0$B00DZ*S1__^%P'1$BSCV1PD$=93'!"0`
M````Z"33__^+`(D$).@*T/__QT0D#`(```#'1"0(`````(E\)`2)!"3H;M/_
M_^E@____D(UT)@"AZ$(%"(U0_SGR#X2``0``QP0D`````.C8TO__BP")!"3H
MOL___\=$)`P%````QT0D"`$```#'1"0$"]`$"(D$).A>S___A<")PW0^BT`,
MBS#'!"0`````Z)?2__^+`(D$).A]S___QT0D"`W0!`B)="0$B00DZ$G/__^+
M0PR+&/9#"D`/A4X!``#'!"0`````Z%[2__^+`(D$).A$S___QT0D#`4```#'
M1"0(`0```,=$)`0ISP0(B00DZ.3.__^%P(G#=#^X"L\$".A(X?__A<")Q@^$
M/@$``(M##(LXQP0D`````.@)TO__BP")!"3H[\[__XET)`B)?"0$B00DZ+_.
M___'!"0`````Z./1__^+`(D$).C)SO__B00DZ$'/___&``#'!"0`````Z,+1
M__^+`(D$).BHSO__B00DZ.#1___'``````"X[<X$".C$X/__A<"CY$(%"`^$
MYP```,=$)`3M`0``B00DZ$/-__^#^!%T#87`=`F#^/\/A2H!``"#Q"Q;7E]=
MPY"-="8`@_@!#XYW_O__NP$```!FD,<$)`````"#PP'H1='__XL`B00DZ"O.
M__^+5>2)5"0$B00DZ,S-__\Y'>A"!0A_T.D[_O__C78`QP0D`````.@0T?__
MBP")!"3H]LW__XE<)`2)!"3HVL___^F+_O__D(!X`0`/A.O\__^-M@````#I
MU/S__XUV`*'L0@4(BSB+0PR+,,<$)`````#HQ-#__XL`B00DZ*K-__^)^8GR
MZ'7@___IO?[__Z'L0@4(B00DZ+/Q__^+/>Q"!0BCY$(%"(M##(LP]D8)!`^$
ME@```(M&#(E\)`2)!"3HAL[__XG&BT,,BQCV0PD$=$:+0PR)1"0(H>Q"!0B)
M="0,BP#'!"0<T00(B40D!.BGS___B40D#*'D0@4(B40D"*'L0@4(BP#'!"1,
MT00(B40D!.B#S___QP0D`````.@7T/__BP")!"3H_<S__\=$)`P"````QT0D
M"`````")7"0$B00DZ&'0___KB<<$)`````#HX\___XL`B00DZ,G,___'1"0,
M`@```,=$)`@`````B70D!(D$).@MT/__Z3;___^-M@````"-OP````!5B>6#
M[!C'!"0`````Z)K/__^+`(D$).B`S/__QT0D#!+0!`C'1"0(_)D$",=$)`0<
MT`0(B00DZ%#/___)PV:058GE@^PHQP0D`````.A:S___BP")!"3H0,S__XD$
M).B<____QP0D`````.@\S___BP")!"3H(LS__\=$)!0`````QT0D$`S0!`C'
M1"0,#-`$",=$)`@`R`0(QT0D!#C0!`B)!"3HTLS__\G#D)"0D%6)Y5/H,@``
M`('#MV,``(/L$(N#4`$``(E$)`R+11")1"0(BT4,B40D!(M%"(D$).@WR___
M@\006UW#BQPDPY!5B>5=PXUT)@"-O"<`````58GE5U93Z.#___^!PV5C``"#
M[!SHT\G__XV[\/[__XV#\/[__RG'P?\"A?]T)#'VBT40B40D"(M%#(E$)`2+
M10B)!"3_E+/P_O__@\8!.?YRWH/$'%M>7UW#D)"0D)"058GE4X/L!*$`,`4(
M@_C_=!.[`#`%"&:0@^L$_]"+`X/X_W7T@\0$6UW#D)!5B>53@^P$Z`````!;
M@</88@``Z+S.__]96\G#`````````````````````````````````P````$`
M`@!005)?0TQ%04X`+W!R;V,O<V5L9B]E>&4`+BX`)7,O)7,`+W!R;V,O)6DO
M)7,`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!015),-4Q)0@!015),3$E"
M`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M4$%27U1%35``4$%27T1%0E5'`%!!4E]#04-(10!005)?4%)/1TY!344`4$%2
M7T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`4$%27T-,14%./0`Q`'!A<BT`+64`+2T`0SI<5$5-4``O=&UP`%1%
M35!$25(`5$U0`%5315(`55-%4DY!344`)7,E<R5S)7,`<&%R;``N<&%R`"5S
M)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE
M=25S`%-94U1%30!!4D=6`!@`<&5R;`!P97)L>'-I+F,`1'EN84QO861E<CHZ
M8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"\`.@````!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!-T`0(3]`$""5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H``"5S.B!S=&%T(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&ES('5N<V%F90H``"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D
M("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@
M=VET:"`E:2X*````````````@/___\]!<&%R+G!L````````````````````
M````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S
M8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM
M92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI
M.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E
M;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A
M=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R
M>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG
M('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@
M("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I
M<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A
M;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A
M(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I
M;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@
M("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O
M=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F
M(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G
M+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@
M("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT
M("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@
M('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V
M+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y
M<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@
M+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE
M>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I
M('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN
M("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?
M,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E
M;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@
M:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D[
M"E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N
M9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P
M;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@
M9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE
M(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@
M('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@
M;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?
M1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?
M1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@
M("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO
M<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@
M("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@
M("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L
M("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@
M("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L
M("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H
M*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO
M)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I
M;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*
M("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S
M92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@
M("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C
M+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@
M("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@
M("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE
M;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*
M("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y
M<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S
M<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@
M;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I
M<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@
M<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I
M;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D
M9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D[
M"B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE
M*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O
M=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@
M("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@
M("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO
M=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ
M92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D
M97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@
M=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E
M<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P
M(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E
M>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA
M;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L
M(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R
M9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A
M<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@
M<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A
M;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@
M<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C
M(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I
M;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H
M92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A
M;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@
M<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@
M("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@
M("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R
M;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@
M=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I
M9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?
M:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@
M("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@
M("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]
M("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@
M("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N
M(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#([
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@
M("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@
M("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@
M("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!0
M05(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M
M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N
M9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C
M:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD[
M"B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@
M("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]
M"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@
M("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M
M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P
M96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@
M7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2
M+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D
M92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A
M=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D
M9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P
M;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]
M"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@
M("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@
M("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@
M("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E
M<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U
M;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R
M97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@
M("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@
M?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P
M('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@
M("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@
M("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S
M="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO
M;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:
M;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I
M9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@
M("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@
M=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F
M86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O
M+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@
M("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R
M+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,[
M"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@
M("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@
M("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV
M93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A
M=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@
M979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS
M,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN
M(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!0
M05(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P
M87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP
M(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@
M)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PH@("`@("`@
M(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D
M;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@
M("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@
M("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@("`@("`@("`@("1U
M<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@
M("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@
M("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H
M+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(
M12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@
M("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@
M("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("!M>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@
M("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@("`@(R!7;W)K87)O
M=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@
M("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA
M;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@("`@:68@*"1C='@@
M86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@("`@
M("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E
M*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D
M14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D
M14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP
M9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R
M8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N
M86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I
M;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@
M('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M
M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^
M)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@
M(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S
M(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T
M7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@
M("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`[
M"@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P
M*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@
M("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@
M("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@
M("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@
M("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@
M("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA
M;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@
M(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@
M("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z
M.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O
M9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D
M)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX[
M"B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`]
M(#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF
M("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?
M8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!
M4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO
M.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@
M("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B([
M"B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]
M"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@
M5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G
M92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I
M;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M
M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?
M15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3(*"E]?14Y$7U\*````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#_____`````/____\```````````$````!`````0```+("
M```!````O0(```$```#'`@```0```!8#```!````6@0```P```",EP0(#0``
M`"S.!`@$````;($$"/7^_V_,A`0(!0```'B-!`@&````*(8$"`H```#X!0``
M"P```!`````5``````````,````0,04(`@```(`"```4````$0```!<````,
ME00($0```.R4!`@2````(````!,````(````_O__;UR4!`C___]O`@```/#_
M_V]PDP0(````````````````````````````````````````````````````
M`````````````````!0P!0@``````````-*7!`CBEP0(\I<$"`*8!`@2F`0(
M(I@$"#*8!`A"F`0(4I@$"&*8!`ARF`0(@I@$")*8!`BBF`0(LI@$",*8!`C2
MF`0(XI@$"/*8!`@"F00($ID$""*9!`@RF00(0ID$"%*9!`ABF00(<ID$"(*9
M!`B2F00(HID$"+*9!`C"F00(TID$".*9!`CRF00(`IH$"!*:!`@BF@0(,IH$
M"$*:!`A2F@0(8IH$"'*:!`B"F@0(DIH$"**:!`BRF@0(PIH$"-*:!`CBF@0(
M\IH$"`*;!`@2FP0((IL$"#*;!`A"FP0(4IL$"&*;!`ARFP0(@IL$")*;!`BB
MFP0(LIL$",*;!`C2FP0(XIL$"/*;!`@"G`0($IP$""*<!`@RG`0(0IP$"%*<
M!`ABG`0(<IP$"(*<!`B2G`0(HIP$"+*<!`C"G`0(``````````#_____J-$$
M".E;``!'0T,Z("A$96)I86X@-"XT+C4M."D@-"XT+C4`1T-#.B`H1&5B:6%N
M(#0N-"XU+3$P*2`T+C0N-0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+F-T
M;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M``````````````L````!`````@```!2!!`@4`0``$P```````````````0``
M```````3````!P````(````H@00(*`$``"````````````````0`````````
M(0````<````"````2($$"$@!```D```````````````$`````````#@````%
M`````@```&R!!`AL`0``8`,```8`````````!`````0````T````]O__;P(`
M``#,A`0(S`0``%P!```&``````````0````$````/@````L````"````*(8$
M""@&``!0!P``!P````$````$````$````$8````#`````@```'B-!`AX#0``
M^`4``````````````0````````!.````____;P(```!PDP0(<!,``.H````&
M``````````(````"````6P```/[__V\"````7)0$"%P4``"0````!P````(`
M```$`````````&H````)`````@```.R4!`CL%```(`````8`````````!```
M``@```!S````"0````(````,E00(#!4``(`"```&````#0````0````(````
M?`````$````&````C)<$"(P7```P```````````````$`````````'<````!
M````!@```+R7!`B\%P``$`4`````````````!`````0```""`````0````8`
M``#0G`0(T!P``%PQ`````````````!``````````B`````$````&````+,X$
M""Q.```<```````````````$`````````(X````!`````@```&#.!`A@3@``
M2E\`````````````(`````````"6`````0````(```"L+04(K*T```0`````
M``````````0`````````H`````$````#`````#`%"`"P```(````````````
M```$`````````*<````!`````P````@P!0@(L```"```````````````!```
M``````"N`````0````,````0,`4($+````0```````````````0`````````
MLP````8````#````%#`%"!2P``#X````!P`````````$````"````+P````!
M`````P````PQ!0@,L0``!```````````````!`````0```#!`````0````,`
M```0,04($+$``$P!``````````````0````$````R@````$````#````7#(%
M"%RR```4```````````````$`````````-`````(`````P```(`R!0APL@``
M<!``````````````(`````````#5`````0```#``````````<+(``#D`````
M``````````$````!`````0````,``````````````*FR``#>````````````
*```!````````````
